@@ -89,7 +89,7 @@ class Topic(TopicABC[T], Generic[T]):
         self.serializer_type = serializer_type
 
     async def serialize(self, header: HeaderABC[T]) -> bytes:
-        return await self.serializer_type.serialize(header.dict())
+        return await self.serializer_type.serialize(header)
 
     async def deserialize(self, serialized: bytes) -> Header[T]:
         data = await self.serializer_type.deserialize(serialized)
@@ -98,7 +98,13 @@ class Topic(TopicABC[T], Generic[T]):
     async def _raw_receive(
         self, queue: Queue[bytes], timeout: Optional[float] = MESSAGING_TIMEOUT
     ) -> Header[T]:
-        message_id, serialized = await asyncio.wait_for(queue.get(), timeout=timeout)
+        try:
+            message_id, serialized = await asyncio.wait_for(
+                queue.get(), timeout=timeout
+            )
+        except asyncio.TimeoutError:
+            raise asyncio.TimeoutError(f"Timed out after {timeout} sec")
+
         header = await self.deserialize(serialized)
         header.message_id = message_id
         return header
@@ -112,7 +118,7 @@ class Topic(TopicABC[T], Generic[T]):
         timeout: Optional[float] = MESSAGING_TIMEOUT,
     ) -> AsyncIterator[Sequence[Header[T]]]:
         queue = await self.messaging._get_queue(self.name)
-        tasks = [self._raw_receive(queue) for i in range(batch_size)]
+        tasks = [self._raw_receive(queue, timeout) for i in range(batch_size)]
         yield await asyncio.gather(*tasks)
 
     async def _ack(self, group_name: str, header: HeaderABC[T]) -> None:
